# softenv-load.csh
# The code that loads the SoftEnv system.
#
# This should be sourced from the /etc/ shell default files for [t]csh.
# This brings the .soft cache up to date, and then sources it.
#
# (This file is designed to modify the user's environment, and therefore
# must be source'd, not executed.)




# ===========================================================================
# Set up variables
# ===========================================================================

# grab the settings from the config file
# softenv.config.pl must be in the same directory

set config_file = !SOFTENV_HOME!/etc/softenv.config.pl

eval `grep '^\$' $config_file | sed -e 's/\$\W*/set /'`

set noglob	# No csh name globbing

set softfile   = $default_softfile
set cachef     = $HOME/.soft.cache.csh
set softname   = "$package_name $version"

alias softcheck 'set use_soft = "\!*"; if ( "$use_soft" == "" ) set use_soft = .soft; !SOFTENV_HOME!/bin/soft-msd -ts; !SOFTENV_HOME!/bin/soft-msc -t $use_soft; source ${HOME}/${use_soft}.cache.csh; unset use_soft'

# ===========================================================================
# Preliminary checks
#   Issue any warnings
#   Look for .soft, check dates.
#   Create one if we're missing one.
# ===========================================================================

# If the user has home dir / or a .nosoft file, exit immediately
if ( "$HOME" == "/" || -f "$nosoftfile" ) then
else

# Issue a warning if there exists a .software of .software-beta file
# This isn't a concern, more of a notice to the user
  if ( $?prompt ) then
    if ( -r $HOME/.software-beta || -r $HOME/.software ) then
      echo "$softname warning:"
      echo "  You have a .software or .software-beta file.  However, this"
      echo "  system is using your .soft file to build your environment."
    endif
  endif


# To make the logic of this program more readable, these two variables
# will be set if we want to run the .soft.cache.sh file or soft-msc
# The default is that we want to run the cache but not msc
  set runcache = "YES"
  set runmsc   = "NO"


# Make a default .soft file if none exists
# If it can't be made, use the ultimate defaults from the login script
  if ( -r "$softfile" ) then
  else
    echo "$softname system warning:"
    echo "  You have no $softfile."
    echo "  Creating the default for you."
    cat > $softfile << EOF
# 
# This is the .soft file.
# It is used to customize your environment by setting up environment
# variables such as PATH and MANPATH.
# To learn what can be in this file, use 'man softenv'.
#
#
@default
EOF
    if ($?) then
      if ($?prompt) then
        echo "$softname system warning:"
        echo "  Unable to create $softfile for you."
        echo "  Using the default environment, which may not be what you want."
      endif
      set runcache="NO"
    endif
  endif


# If the .soft.cache.sh file doesn't exist, or if the time conditions are
# true, then we want to run soft-msc
  if ( -r $cachef ) then
    if ( "`find $softfile -newer $cachef -print`" != "" || "`find $system_db -newer $cachef -print`" != "" ) then
      set runmsc="YES"
    endif
  else
     set runmsc="YES"
  endif


# If runmsc="YES", then run the soft-msc program, which will return values
# that determine if we want to run the cache
  if ( "$runmsc" == "YES" ) then
    if ($?prompt) then
      echo "$softname"": updating your software environment, one moment..."
    endif

    ${prefix}/bin/soft-msc -s ${softfile}

    switch ($status)
      case 1:
        echo "$softname system error: unspecific error"
        set runcache = "NO"
        breaksw
      case 2:
        echo "$softname system error: weird environment.  are you root?"
        set runcache = "NO"
        breaksw
      case 3:
        echo "$softname system error: could not create the file: $cachef"
        set runcache = "NO"
        breaksw
      case 4:
        echo "$softname system error: errors occured in writing $cachef"
        set runcache = "NO"
        breaksw
      case 5:
        echo "$softname system error: $cachef was locked"
        echo "Try deleting any files ending in .lock and running resoft"
        set runcache = "NO"
        breaksw
      case 10:
        echo "$softname system warning: no .soft was found"
        breaksw
      case 11:
        echo "$softname system warning: some words were not recognized"
        echo "Examine $cachef for error details."
        breaksw
      case 12:
        echo "$softname system warning: $cachef was locked"
        echo "However, it appeared to be old and execution was completed"
        breaksw
    endsw
  endif


# Source the .soft.cache.sh file if the rest of this script went smoothly
  if ( "$runcache" == "YES" ) then
    source $cachef
  endif


# and unset the variables that we used
endif
unset noglob softfile cachef softname runcache runmsc
unset package_name version prefix dbpath system_db beta_db auto_db
unset database default_softfile nosoftfile test_database htmllog
